"""
PCILeech Firmware Generator TUI Package

This package provides a modern Text User Interface (TUI) for the PCILeech
firmware generation workflow, built with Textual framework.
"""

__version__ = "0.5.0"
__author__ = "Ramsey McGrath"

from .main import PCILeechTUI

__all__ = ["PCILeechTUI"]
